
## CATO-CLI - mutation.site.removeSite:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.site.removeSite) for documentation on this operation.

### Usage for mutation.site.removeSite:

`catocli mutation site removeSite -h`

`catocli mutation site removeSite <json>`

`catocli mutation site removeSite "$(cat < mutation.site.removeSite.json)"`

`catocli mutation site removeSite '{"siteId":"id"}'`

`catocli mutation site removeSite -p '{
    "siteId": "id"
}'`


#### Operation Arguments for mutation.site.removeSite ####

`accountId` [ID] - (required) N/A    
`siteId` [ID] - (required) N/A    
